==> nextcloud-19.0.3.tgz: nextcloud/apps/dav/l10n/nb.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Gjøremål",
    "Personal" : "Personlig",
    "{actor} created calendar {calendar}" : "{actor} opprettet kalenderen {calendar}",
    "You created calendar {calendar}" : "Du opprettet kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} slettet kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettet kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} oppdaterte kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du oppdaterte kalenderen {calendar}",
    "You shared calendar {calendar} as public link" : "Du delte kalenderen {calendar} som offentlig lenke",
    "You removed public link for calendar {calendar}" : "Du fjernet offentlig lenke for kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med deg",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} opphevde delingen av kalenderen {calendar} med deg",
    "You unshared calendar {calendar} from {user}" : "Du opphevde delingen av kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} opphevde delingen av kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} opphevde delingen av kalender {calendar} med seg selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalender {calendar} med gruppe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Du opphevde deling av kalenderen {calendar} med gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} opphevde deling av kalenderen {calendar} med gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} opprettet en hendelse {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du opprettet en hendelse {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettet hendelsen {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettet hendelsen {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} oppdaterte hendelsen {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du oppdaterte hendelsen {event} i kalenderen {calendar}",
    "Busy" : "Opptatt",
    "{actor} created todo {todo} in list {calendar}" : "{actor} opprettet en oppgaven {todo} i listen {calendar}",
    "You created todo {todo} in list {calendar}" : "Du opprettet en oppgave {todo} i listen {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettet gjøremålet {todo} fra listen {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du slettet gjøremålet {todo} fra listen {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} oppdaterte gjøremålet {todo} i listen {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du oppdaterte gjøremålet {todo} i listen {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ferdigstilte gjøremålet {todo} i listen {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du ferdigstilte gjøremålet {todo} i listen {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} gjenåpnet gjøremålet {todo} i listen {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du gjenåpnet oppgaven {todo} i listen {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> ble endret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>hendelse</strong> ble endret",
    "A calendar <strong>todo</strong> was modified" : "En kalende <strong>gjøremål</strong> ble endret",
    "Contact birthdays" : "Kontakters fødelsdag",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Invitasjon tilbakekalt",
    "Invitation updated" : "Invitasjon oppdatert",
    "Location:" : "Sted:",
    "Link:" : "Lenke:",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Contacts" : "Kontakter",
    "Tasks" : "Oppgaver",
    "WebDAV" : "WebDAV",
    "Tentative" : "Foreløpig",
    "Save" : "Lagre",
    "Calendar server" : "Kalenderserver",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer også {calendarappstoreopen} Kalender-appen {linkclose}, eller {calendardocopen} knytt datamaskinen og mobilen din for synkronisering ↗{linkclose}.",
    "Send invitations to attendees" : "Send invitasjoner til oppmøtte",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Vennligst sørg for å sette opp {emailopen}e-postinnstillingene{linkclose} på riktig måte.",
    "Automatically generate a birthday calendar" : "Lag fødelsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalender lages automatisk av en bakgrunnsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derav vil de ikke være tilgjengelige umiddelbart etter at du har skrudd dem på, men vil vises etter en stund.",
    "Hello %s," : "Hei %s,",
    "When:" : "Når:",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Ekstern adresse: %s",
    "Request ID: %s" : "Forespørsel ID: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.10.tgz: nextcloud/apps/dav/l10n/nb.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Gjøremål",
    "Personal" : "Personlig",
    "{actor} created calendar {calendar}" : "{actor} opprettet kalenderen {calendar}",
    "You created calendar {calendar}" : "Du opprettet kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} slettet kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettet kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} oppdaterte kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du oppdaterte kalenderen {calendar}",
    "You shared calendar {calendar} as public link" : "Du delte kalenderen {calendar} som offentlig lenke",
    "You removed public link for calendar {calendar}" : "Du fjernet offentlig lenke for kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med deg",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} opphevde delingen av kalenderen {calendar} med deg",
    "You unshared calendar {calendar} from {user}" : "Du opphevde delingen av kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} opphevde delingen av kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} opphevde delingen av kalender {calendar} med seg selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalender {calendar} med gruppe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Du opphevde deling av kalenderen {calendar} med gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} opphevde deling av kalenderen {calendar} med gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} opprettet en hendelse {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du opprettet en hendelse {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettet hendelsen {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettet hendelsen {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} oppdaterte hendelsen {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du oppdaterte hendelsen {event} i kalenderen {calendar}",
    "Busy" : "Opptatt",
    "{actor} created todo {todo} in list {calendar}" : "{actor} opprettet en oppgaven {todo} i listen {calendar}",
    "You created todo {todo} in list {calendar}" : "Du opprettet en oppgave {todo} i listen {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettet gjøremålet {todo} fra listen {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du slettet gjøremålet {todo} fra listen {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} oppdaterte gjøremålet {todo} i listen {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du oppdaterte gjøremålet {todo} i listen {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ferdigstilte gjøremålet {todo} i listen {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du ferdigstilte gjøremålet {todo} i listen {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} gjenåpnet gjøremålet {todo} i listen {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du gjenåpnet oppgaven {todo} i listen {calendar}",
    "Calendar and tasks" : "Kalender og oppgaver",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> ble endret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>hendelse</strong> ble endret",
    "A calendar <strong>todo</strong> was modified" : "En kalende <strong>gjøremål</strong> ble endret",
    "Contact birthdays" : "Kontakters fødelsdag",
    "Death of %s" : "Død av %s",
    "Calendar:" : "Kalender:",
    "Date:" : "Dato:",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "Untitled event" : "Hendelse uten tittel",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n måned","%n måneder"],
    "_%n day_::_%n days_" : ["%n dag","%n dager"],
    "_%n hour_::_%n hours_" : ["%n time","%n timer"],
    "_%n minute_::_%n minutes_" : ["%n minutt","%n minutter"],
    "%s (in %s)" : "%s (i %s)",
    "%s (%s ago)" : "%s (%s siden)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Dato: %s",
    "Description: %s" : "Beskrivelse: %s",
    "Where: %s" : "Hvor: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Invitasjon tilbakekalt",
    "Invitation updated" : "Invitasjon oppdatert",
    "Invitation" : "Invitasjon",
    "Title:" : "Tittel:",
    "Time:" : "Tid:",
    "Location:" : "Sted:",
    "Link:" : "Lenke:",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Deltakere:",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "More options …" : "Flere alternativer ...",
    "More options at %s" : "Flere alternativer ved %s",
    "Contacts" : "Kontakter",
    "System in maintenance mode." : "System i vedlikeholdsmodus.",
    "Upgrade needed" : "Oppgradering er nødvendig",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Din %s må konfigureres til å bruke HTTPS for å kunne bruke CalDAV og CardDAV med iOS/macOS.",
    "Configures a CalDAV account" : "Konfigurerer en CalDAV konto",
    "Configures a CardDAV account" : "Konfigurerer en CardDAV konto",
    "Events" : "Hendelser",
    "Tasks" : "Oppgaver",
    "Untitled task" : "Oppgave uten tittel",
    "Completed on %s" : "Ferdig på %s",
    "Due on %s by %s" : "Forfaller på %s ved %s",
    "Due on %s" : "Forfaller på %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endepunkt",
    "There was an error updating your attendance status." : "Det oppsto en feil under oppdateringen av oppmøtestatusen din.",
    "Please contact the organizer directly." : "Ta kontakt med arrangøren direkte.",
    "Are you accepting the invitation?" : "Aksepterer du invitasjonen?",
    "Tentative" : "Foreløpig",
    "Save" : "Lagre",
    "Your attendance was updated successfully." : "Deltakelsen din ble oppdatert.",
    "Calendar server" : "Kalenderserver",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer også {calendarappstoreopen} Kalender-appen {linkclose}, eller {calendardocopen} knytt datamaskinen og mobilen din for synkronisering ↗{linkclose}.",
    "Send invitations to attendees" : "Send invitasjoner til oppmøtte",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Vennligst sørg for å sette opp {emailopen}e-postinnstillingene{linkclose} på riktig måte.",
    "Automatically generate a birthday calendar" : "Lag fødelsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalender lages automatisk av en bakgrunnsjobb.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derav vil de ikke være tilgjengelige umiddelbart etter at du har skrudd dem på, men vil vises etter en stund.",
    "Send notifications for events" : "Send varsler om hendelser",
    "Notifications are sent via background jobs, so these must occur often enough." : "Varsler sendes via bakgrunnsjobber, så disse må forekomme ofte nok.",
    "Enable notifications for events via push" : "Aktiver varsler for hendelser via push",
    "Hello %s," : "Hei %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Møtet »%1$s« med %2$s ble kansellert.",
    "The meeting »%1$s« with %2$s was updated." : "Møtet »%1$s« med %2$s ble oppdatert.",
    "%1$s invited you to »%2$s«" : "%1$sinviterte deg til »%2$s«",
    "When:" : "Når:"
},
"nplurals=2; plural=(n != 1);");
